Learn R Programming

josaplay (version 0.1.3)

josaplay-package: josaplay: Add Josa Based on Previous Letter in Korean

Description

Josa in Korean is often determined by judging the previous word. When writing reports using Rmd, a function that prints the appropriate investigation for each case is helpful. The 'josaplay' package then evaluates the previous word to determine which josa is appropriate.

Arguments

See Also

Useful links: